@@ -1,35 +1,49 @@
 """
 Hyphenates an HTML fragement using soft hyphens
 
-Author: Filipe Fortes
+Author by Filipe Fortes, modified by Ben Welsh
 """
+from __future__ import absolute_import
+
 import os
 import re
-from hyphenator import Hyphenator
-from BeautifulSoup import BeautifulSoup, NavigableString
+import six
+from bs4 import BeautifulSoup
+from .hyphenator import Hyphenator
+from bs4.element import PreformattedString
+
+
+class DontEscapeDammit(PreformattedString):
+    """
+    A BeautifulSoup trick that lets us insert a `&shy;` into the HTML
+    without BS escaping the `&` and turning it into `&amp;shy;`.
+    """
+    def output_ready(self, formatter=None):
+        self.format_string(self, formatter)
+        return self.PREFIX + self + self.SUFFIX
 
 
 def hyphenate(html, language='en-us', hyphenator=None, blacklist_tags=(
     'code', 'tt', 'pre', 'head', 'title', 'script', 'style', 'meta', 'object',
     'embed', 'samp', 'var', 'math', 'select', 'option', 'input', 'textarea',
-    'span',
-    )):
+    'span')
+        ):
     """
     Hyphenate a fragement of HTML
 
-    >>> hyphenate_html('<p>It is <em>beautiful</em> outside today!</p>')
+    >>> hyphenate('<p>It is <em>beautiful</em> outside today!</p>')
     u'<p>It is <em>beau&shy;ti&shy;ful</em> out&shy;side today!</p>'
 
-    >>> hyphenate_html('O paralelepipedo atrevessou a rua', 'pt-br')
-    u'O pa&shy;ra&shy;le&shy;le&shy;pi&shy;pe&shy;do atre&shy;ves&shy;sou a rua'
+    >>> hyphenate('O paralelepipedo atrevessou', 'pt-br')
+    u'O pa&shy;ra&shy;le&shy;le&shy;pi&shy;pe&shy;do atre&shy;ves&shy;sou'
 
     Content inside <code>, <tt>, and <pre> blocks is not hyphenated
-    >>> hyphenate_html('Document: <code>document + page_status</code>')
+    >>> hyphenate('Document: <code>document + page_status</code>')
     u'Doc&shy;u&shy;ment: <code>document + page_status</code>'
 
     Short words are not hyphenated
 
-    >>> hyphenate_html("<p>The brave men, living and dead.</p>")
+    >>> hyphenate("<p>The brave men, living and dead.</p>")
     u'<p>The brave men, liv&shy;ing and dead.</p>'
     """
     # Load hyphenator if one is not provided
@@ -42,13 +56,14 @@ def hyphenate(html, language='en-us', hyphenator=None, blacklist_tags=(
     # Recursively hyphenate each element
     hyphenate_element(soup, hyphenator, blacklist_tags)
 
-    return unicode(soup)
+    return six.text_type(soup)
 
 
 # Constants
 SOFT_HYPHEN = r'&shy;'
 SPACE = r' '
-STRIP_WHITESPACE = re.compile('\w+', re.MULTILINE)
+STRIP_WHITESPACE = re.compile('\w+', re.MULTILINE | re.UNICODE)
+
 
 def hyphenate_element(soup, hyphenator, blacklist_tags):
     """
@@ -57,20 +72,21 @@ def hyphenate_element(soup, hyphenator, blacklist_tags):
     """
     # Blacklist function
     BLACKLIST = lambda tag: tag in blacklist_tags
-    
+
     # Find any element with text in it
-    paragraphs = soup.findAll(text = lambda text: len(text) > 0)
+    paragraphs = soup.findAll(text=lambda text: len(text) > 0)
     for paragraph in paragraphs:
         # Make sure element isn't on blacklist
         if not BLACKLIST(paragraph.parent.name):
             # Replace text with hyphened version
-            paragraph.replaceWith(STRIP_WHITESPACE.sub(
-                (lambda x: hyphenator.inserted(x.group(), SOFT_HYPHEN)), paragraph)
+            new_string = STRIP_WHITESPACE.sub(
+                (lambda x: hyphenator.inserted(x.group(), SOFT_HYPHEN)),
+                paragraph
             )
+            paragraph.replaceWith(DontEscapeDammit(new_string))
     return soup
-            
 
-    
+
 DICTIONARIES = {
     'cs-cz': 'hyph_cs_CZ',
     'da-dk': 'hyph_da_DK',
@@ -102,6 +118,8 @@ DICTIONARIES = {
     'sv-se': 'hyph_sv_SE',
     'uk-ua': 'hyph_uk_UA'
 }
+
+
 def get_hyphenator_for_language(language):
     """
     Create a Hyphenator for the given language. Uses English if the
@@ -121,11 +139,13 @@ def get_hyphenator_for_language(language):
     )
     return Hyphenator(path)
 
+
 # Test when standalone
 def _test():
     """Run doctests"""
     import doctest
     doctest.testmod(verbose=True)
 
+
 if __name__ == '__main__':
     _test()
